@@ -1,11 +1,12 @@
-use anyhow::{anyhow, Context, Result};
-use clap::{ArgEnum, Args, Parser, ValueHint};
-use clap_verbosity_flag::Verbosity;
-use cli::input::Input;
 use std::{
     io::{stdin, stdout, Write},
     path::PathBuf,
 };
+
+use anyhow::{anyhow, Context, Result};
+use clap::{ArgEnum, Args, Parser, ValueHint};
+use clap_verbosity_flag::Verbosity;
+use cli::input::Input;
 use xq::{module_loader::PreludeLoader, run_query, InputError, Value};
 
 use crate::cli::input::Tied;
@@ -69,7 +70,7 @@ struct InputFormatArg {
 }
 
 impl InputFormatArg {
-    fn get(&self) -> SerializationFormat {
+    fn get(self) -> SerializationFormat {
         if self.json_input {
             SerializationFormat::Json
         } else if self.yaml_input {
@@ -101,7 +102,7 @@ struct OutputFormatArg {
 }
 
 impl OutputFormatArg {
-    fn get(&self) -> SerializationFormat {
+    fn get(self) -> SerializationFormat {
         if self.json_output {
             SerializationFormat::Json
         } else if self.yaml_output {
