@@ -1,12 +1,3 @@
-use crate::Number;
-use derive_more::{DebugCustom, Display, Index, IndexMut, IntoIterator, IsVariant, Unwrap};
-use itertools::Itertools;
-use num::Float;
-use serde::{
-    de::{Error, MapAccess, SeqAccess, Visitor},
-    ser::{SerializeMap, SerializeSeq},
-    serde_if_integer128, Deserialize, Deserializer, Serialize, Serializer,
-};
 use std::{
     borrow::Borrow,
     cmp::Ordering,
@@ -19,6 +10,17 @@ use std::{
     slice::SliceIndex,
 };
 
+use derive_more::{DebugCustom, Display, Index, IndexMut, IntoIterator, IsVariant, Unwrap};
+use itertools::Itertools;
+use num::Float;
+use serde::{
+    de::{Error, MapAccess, SeqAccess, Visitor},
+    ser::{SerializeMap, SerializeSeq},
+    serde_if_integer128, Deserialize, Deserializer, Serialize, Serializer,
+};
+
+use crate::Number;
+
 type Vector = Vec<Value>;
 type Map = HashMap<RcString, Value>;
 pub type RcString = Rc<String>;
@@ -38,7 +40,7 @@ pub struct Object(#[into_iterator(owned, ref, ref_mut)] Map);
 #[allow(clippy::derive_hash_xor_eq)] // HashMap::eq is implemented properly.
 impl Hash for Object {
     fn hash<H: Hasher>(&self, state: &mut H) {
-        for (key, value) in self.0.iter().sorted_by_key(|e| e.0) {
+        for (key, value) in self.0.iter().sorted_unstable_by_key(|e| e.0) {
             key.hash(state);
             value.hash(state);
         }
@@ -456,8 +458,8 @@ impl Ord for Value {
             (String(lhs), String(rhs)) => Ord::cmp(&lhs, &rhs),
             (Array(lhs), Array(rhs)) => return Iterator::cmp(lhs.iter(), rhs.iter()),
             (Object(lhs), Object(rhs)) => {
-                let lhs_keys = lhs.keys().sorted().collect_vec();
-                let rhs_keys = rhs.keys().sorted().collect_vec();
+                let lhs_keys = lhs.keys().sorted_unstable().collect_vec();
+                let rhs_keys = rhs.keys().sorted_unstable().collect_vec();
                 if let res @ (Less | Greater) = Iterator::cmp(lhs_keys.iter(), rhs_keys.iter()) {
                     return res;
                 }
